SystemOrganization addCategory: #ConfigurationOfMocketry!

Object subclass: #ConfigurationOfMocketry
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfMocketry'!

!ConfigurationOfMocketry class methodsFor: 'private' stamp: 'LaurentLaffont 11/29/2010 20:37'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfMocketry class methodsFor: 'private' stamp: 'LaurentLaffont 11/29/2010 20:37'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfMocketry class methodsFor: 'metacello tool support' stamp: 'LaurentLaffont 11/29/2010 20:37'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfMocketry class methodsFor: 'metacello tool support' stamp: 'LaurentLaffont 11/29/2010 20:37'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfMocketry class methodsFor: 'loading' stamp: 'LaurentLaffont 11/29/2010 20:37'!
load
	"self load"

	^self project stableVersion load! !

!ConfigurationOfMocketry class methodsFor: 'metacello tool support' stamp: 'LaurentLaffont 11/29/2010 20:37'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfMocketry class methodsFor: 'accessing' stamp: 'LaurentLaffont 11/29/2010 20:37'!
project

	^self new project! !

!ConfigurationOfMocketry class methodsFor: 'unloading Metacello' stamp: 'LaurentLaffont 11/29/2010 20:37'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfMocketry methodsFor: 'baselines' stamp: 'LaurentLaffont 11/30/2010 20:05'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/Mocketry'.	
		spec 
			package: 'SMock';
			package: 'Mocketry';
			package: 'MocketryTests' with: [ spec requires: 'Mocketry'; requires: 'SMock' ].
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('Mocketry');
			group: 'Tests' with: #('MocketryTests'). ].! !

!ConfigurationOfMocketry methodsFor: 'accessing' stamp: 'LaurentLaffont 11/29/2010 20:37'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfMocketry methodsFor: 'versions' stamp: 'dik 5/27/2012 15:13'!
stable: spec
	<symbolicVersion: #stable>
	spec for: #common version: '1.1'! !

!ConfigurationOfMocketry methodsFor: 'versions' stamp: 'dik 2/25/2011 21:40'!
version10: spec 
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'Mocketry is a  mock objects framework with SSpec functionality'.
		spec 
			package: 'Mocketry' with: 'Mocketry-LaurentLaffont.21';
			package: 'MocketryTests' with: 'MocketryTests-dik.14';
			package: 'SMock' with:'SMock-LaurentLaffont.12';
			package: 'SMock-SUnit' with: 'SMock-SUnit-JohanBrichau.2'].! !

!ConfigurationOfMocketry methodsFor: 'versions' stamp: 'dik 5/27/2012 15:22'!
version11: spec 
	<version: '1.1' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'Mocketry is a  mock objects framework with SSpec functionality'.
		spec 
			package: 'Mocketry' with: 'Mocketry-LaurentLaffont.21';
			package: 'MocketryTests' with: 'MocketryTests-dik.14';
			package: 'SMock' with:'SMock-dik.13';
			package: 'SMock-SUnit' with: 'SMock-SUnit-JohanBrichau.2'].! !
